yt.visualization.volume_rendering.transfer_functions.TransferFunction.plot — The yt Project 3.2-dev documentation

# yt.visualization.volume_rendering.transfer_functions.TransferFunction.plot

`TransferFunction.` `plot`(filename)

  Save an image file of the transfer function.

  This function loads up matplotlib, plots the transfer function and saves.

  Parameters: | filename : string The file to save out the plot as.

  Examples

      >>> tf = TransferFunction( (-10.0, -5.0) )
      >>> tf.add_gaussian(-9.0, 0.01, 1.0)
      >>> tf.plot("sample.png")